
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.008.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Convert from PML to SQL",
  "dist_author" => [
    "Petr Pajas <pajas\@ufal.mff.cuni.cz>",
    "Jan \x{160}t\x{11b}p\x{e1}nek <stepanek\@ufal.mff.cuni.cz>",
    "Michal Sedl\x{e1}k <sedlak\@ufal.mff.cuni.cz>",
    "Maty\x{e1}\x{161} Kopp <matyas.kopp\@gmail.com>"
  ],
  "dist_name" => "PMLTQ-PML2BASE",
  "dist_version" => "3.0.1",
  "license" => "perl",
  "module_name" => "PMLTQ::PML2BASE",
  "recursive_test_files" => 1,
  "requires" => {
    "PMLTQ" => "v3.0.0"
  },
  "test_requires" => {
    "File::Spec" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Test::More" => 0,
    "Test::Most" => 0
  }
);


my %fallback_build_requires = (
  "File::Spec" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Module::Build" => "0.28",
  "Test::More" => 0,
  "Test::Most" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

if ( $^O =~ /^(aix|android|bitrig|bsdos|cygwin|darwin|dgux|dragonfly|dynixptx|freebsd|gnukfreebsd|hpux|interix|irix|linux|machten|midnightbsd|mirbsd|netbsd|next|nto|openbsd|qnx|sco|solaris)$/i ) {
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
